const NavigationContainer = {
    slug: 'navigation-containers',
    access: {
        read: ()=>true
    },
    admin: {
        components: {},
        defaultColumns: [
            'name',
            'slug',
            'updatedAt'
        ],
        description: 'Create and manage navigation menus',
        useAsTitle: 'name'
    },
    fields: [
        {
            name: 'name',
            type: 'text',
            admin: {
                description: 'The name of this navigation menu (e.g. "Main Menu", "Footer")'
            },
            localized: true,
            required: true
        },
        {
            name: 'slug',
            type: 'text',
            admin: {
                description: 'URL-friendly identifier for this navigation menu'
            },
            required: true,
            unique: true
        },
        {
            name: 'description',
            type: 'textarea',
            admin: {
                description: 'Optional description of this navigation menu'
            },
            localized: true
        },
        {
            name: 'items',
            type: 'relationship',
            admin: {
                description: 'Navigation items in this container (root level items only)'
            },
            hasMany: true,
            relationTo: 'navigation-items'
        },
        {
            name: 'settings',
            type: 'group',
            admin: {
                description: 'Settings for this navigation container'
            },
            fields: [
                {
                    name: 'maxDepth',
                    type: 'number',
                    admin: {
                        description: 'Maximum nesting depth for items in this navigation'
                    },
                    defaultValue: 3,
                    max: 10,
                    min: 1
                },
                {
                    name: 'allowedTypes',
                    type: 'select',
                    admin: {
                        description: 'Types of navigation items allowed in this container'
                    },
                    defaultValue: [
                        'internal',
                        'external',
                        'folder'
                    ],
                    hasMany: true,
                    options: [
                        {
                            label: 'Internal Link',
                            value: 'internal'
                        },
                        {
                            label: 'External URL',
                            value: 'external'
                        },
                        {
                            label: 'Folder/Wrapper',
                            value: 'folder'
                        }
                    ]
                }
            ]
        }
    ],
    hooks: {
    },
    timestamps: true
};
export default NavigationContainer;

//# sourceMappingURL=NavigationContainer.js.map