const NavigationItem = {
    slug: 'navigation-items',
    access: {
        read: ()=>true
    },
    admin: {
        defaultColumns: [
            'title',
            'type',
            'updatedAt'
        ],
        description: 'Navigation menu items',
        useAsTitle: 'title'
    },
    fields: [
        {
            name: 'title',
            type: 'text',
            admin: {
                description: 'The display text for this navigation item'
            },
            localized: true,
            required: true
        },
        {
            name: 'type',
            type: 'select',
            admin: {
                description: 'The type of navigation item'
            },
            defaultValue: 'internal',
            options: [
                {
                    label: 'Internal Link',
                    value: 'internal'
                },
                {
                    label: 'External URL',
                    value: 'external'
                },
                {
                    label: 'Folder/Wrapper',
                    value: 'folder'
                }
            ],
            required: true
        },
        {
            name: 'parent',
            type: 'relationship',
            admin: {
                condition: (data)=>data?.type !== 'folder',
                description: 'Parent item (for nested navigation)'
            },
            relationTo: 'navigation-items'
        },
        {
            name: 'order',
            type: 'number',
            admin: {
                description: 'Order within the navigation level (lower numbers appear first)'
            },
            defaultValue: 0
        },
        {
            name: 'url',
            type: 'text',
            admin: {
                condition: (data)=>data?.type === 'external',
                description: 'URL for external links'
            },
            // @ts-ignore - Validation type mismatch
            validate: (value, { data })=>{
                if (data?.type === 'external' && !value) {
                    return 'External links must have a URL';
                }
                return true;
            }
        },
        {
            name: 'internalLink',
            type: 'group',
            admin: {
                condition: (data)=>data?.type === 'internal',
                description: 'Internal link settings'
            },
            fields: [
                {
                    name: 'reference',
                    type: 'relationship',
                    admin: {
                        description: 'Content to link to'
                    },
                    relationTo: [
                        'pages'
                    ],
                    required: true
                },
                {
                    name: 'customPath',
                    type: 'text',
                    admin: {
                        description: 'Optional custom path (overrides auto-generated path)'
                    }
                }
            ]
        },
        {
            name: 'target',
            type: 'select',
            admin: {
                condition: (data)=>data?.type !== 'folder',
                description: 'Where to open the link'
            },
            defaultValue: '_self',
            options: [
                {
                    label: 'Same Window',
                    value: '_self'
                },
                {
                    label: 'New Window',
                    value: '_blank'
                }
            ]
        },
        {
            name: 'children',
            type: 'relationship',
            admin: {
                description: 'Child navigation items'
            },
            hasMany: true,
            relationTo: 'navigation-items'
        },
        {
            name: 'localeVisibility',
            type: 'array',
            admin: {
                description: 'Control visibility per locale'
            },
            fields: [
                {
                    name: 'locale',
                    type: 'text',
                    required: true
                },
                {
                    name: 'visible',
                    type: 'checkbox',
                    defaultValue: true
                }
            ]
        },
        {
            name: 'active',
            type: 'checkbox',
            admin: {
                description: 'Whether this item is active/visible'
            },
            defaultValue: true
        },
        {
            name: 'className',
            type: 'text',
            admin: {
                description: 'Optional CSS class to apply to this item'
            }
        }
    ],
    hooks: {
    },
    timestamps: true
};
export default NavigationItem;

//# sourceMappingURL=NavigationItem.js.map