/**
 * Navigation item type options
 */
export type NavigationItemType = 'external' | 'folder' | 'internal';
/**
 * Link target options
 */
export type LinkTarget = '_blank' | '_self';
/**
 * Navigation item structure
 */
export interface NavigationItem {
    active: boolean;
    children?: NavigationItem[] | string[];
    className?: null | string;
    id: string;
    internalLink?: {
        customPath?: null | string;
        reference: {
            id: string;
            relationTo: string;
        } | string;
    } | null;
    localeVisibility?: {
        locale: string;
        visible: boolean;
    }[];
    order: number;
    parent?: null | string;
    target?: LinkTarget;
    title: Record<string, string> | string;
    type: NavigationItemType;
    url?: null | string;
}
/**
 * Navigation container structure
 */
export interface NavigationContainer {
    description?: null | string;
    id: string;
    items: NavigationItem[] | string[];
    name: string;
    settings: {
        allowedTypes: NavigationItemType[];
        maxDepth: number;
    };
    slug: string;
}
/**
 * Navigation renderer types
 */
export type NavigationFormat = 'breadcrumb' | 'flat' | 'tree';
/**
 * Navigation API query options
 */
export interface NavigationQuery {
    depth?: number;
    format?: NavigationFormat;
    includeHidden?: boolean;
    locale?: string;
}
/**
 * Navigation item with nested path
 */
export interface FlatNavigationItem extends Omit<NavigationItem, 'children'> {
    level: number;
    parentPath?: string;
    path: string;
}
/**
 * Navigation item with full children tree
 */
export interface TreeNavigationItem extends Omit<NavigationItem, 'children'> {
    items: TreeNavigationItem[];
    path: string;
}
/**
 * Breadcrumb navigation item
 */
export interface BreadcrumbItem {
    isActive: boolean;
    path: string;
    title: Record<string, string> | string;
}
